@@ -7,22 +7,26 @@
 // permissions and limitations relating to use of the SAFE Network Software.
 
 mod blob_apis;
-mod blob_storage;
 mod commands;
+mod data;
 mod queries;
 mod register_apis;
 
+pub use self::blob_apis::BlobAddress;
 use crate::client::{connections::Session, errors::Error, Config};
-use crate::messaging::data::{CmdError, DataCmd};
+use crate::messaging::data::CmdError;
 use crate::types::{Chunk, ChunkAddress, Keypair, PublicKey};
+
 use lru::LruCache;
 use rand::rngs::OsRng;
+use std::collections::BTreeSet;
+use std::net::SocketAddr;
 use std::sync::Arc;
 use tokio::{
     sync::{mpsc::Receiver, RwLock},
     time::Duration,
 };
-use tracing::info;
+use tracing::{debug, info};
 
 const BLOB_CACHE_CAP: usize = 150;
 
@@ -50,7 +54,11 @@ impl Client {
     ///
     /// TODO: update once data types are crdt compliant
     ///
-    pub async fn new(optional_keypair: Option<Keypair>, config: Config) -> Result<Self, Error> {
+    pub async fn new(
+        config: Config,
+        bootstrap_nodes: BTreeSet<SocketAddr>,
+        optional_keypair: Option<Keypair>,
+    ) -> Result<Self, Error> {
         let mut rng = OsRng;
 
         let keypair = match optional_keypair {
@@ -73,13 +81,17 @@ impl Client {
 
         let client_pk = keypair.public_key();
 
-        // Create the session with the network
-        let session = Session::new(
+        // Bootstrap to the network, connecting to a section based
+        // on a public key of our choice.
+        debug!("Bootstrapping to the network...");
+        // Create a session with the network
+        let session = Session::attempt_bootstrap(
             client_pk,
-            config.local_addr,
-            &config.bootstrap_nodes,
             config.qp2p,
+            bootstrap_nodes.clone(),
+            config.local_addr,
             err_sender,
+            0,
         )
         .await?;
 
@@ -116,12 +128,6 @@ impl Client {
         self.keypair().public_key()
     }
 
-    // Private helper to obtain payment proof for a data command, send it to the network,
-    // and also apply the payment to local replica actor.
-    async fn pay_and_send_data_command(&self, cmd: DataCmd) -> Result<(), Error> {
-        self.send_cmd(cmd).await
-    }
-
     #[cfg(test)]
     pub async fn expect_cmd_error(&mut self) -> Option<CmdError> {
         self.incoming_errors.write().await.recv().await
@@ -132,6 +138,8 @@ impl Client {
 mod tests {
     use super::*;
     use crate::client::utils::test_utils::{create_test_client, create_test_client_with};
+    use crate::types::utils::random_bytes;
+    use crate::url::Scope;
     use eyre::Result;
     use std::{
         collections::HashSet,
@@ -174,9 +182,8 @@ mod tests {
     async fn long_lived_connection_survives() -> Result<()> {
         let client = create_test_client(None).await?;
         tokio::time::sleep(tokio::time::Duration::from_secs(40)).await;
-
-        let _ = client.store_private_blob(&[0, 1, 2, 3, 4]).await?;
-
+        let data = random_bytes(self_encryption::MIN_ENCRYPTABLE_BYTES);
+        let _ = client.write_to_network(data, Scope::Public).await?;
         Ok(())
     }
 
