@@ -43,16 +43,15 @@ use assert_matches::assert_matches;
 use bls_dkg::message::Message;
 use ed25519_dalek::Signer;
 use eyre::{bail, eyre, Context, Result};
-use rand::rngs::OsRng;
-use rand::{distributions::Alphanumeric, Rng};
+use rand::{distributions::Alphanumeric, rngs::OsRng, Rng};
 use resource_proof::ResourceProof;
 use secured_linked_list::SecuredLinkedList;
-use std::path::Path;
 use std::{
     collections::{BTreeMap, BTreeSet, HashSet},
     iter,
     net::Ipv4Addr,
     ops::Deref,
+    path::Path,
 };
 use tempfile::tempdir;
 use tokio::{
@@ -247,7 +246,6 @@ async fn receive_join_request_from_relocated_node() -> Result<()> {
     let payload = WireMsg::serialize_msg_payload(&relocate_node_msg)?;
     let signature = sk_set.secret_key().sign(&payload);
     let section_signed = MsgKindSectionAuth {
-        section_pk: section_key,
         src_name: node_name,
         sig: KeyedSig {
             public_key: section_key,
@@ -893,7 +891,6 @@ async fn handle_untrusted_accumulated_message() -> Result<()> {
     let payload = WireMsg::serialize_msg_payload(&original_node_msg)?;
     let expected_recipients = vec![sender];
     let msg_kind = MsgKind::SectionAuthMsg(MsgKindSectionAuth {
-        section_pk: pk1,
         src_name: Prefix::default().name(),
         sig: KeyedSig {
             public_key: pk1,
